export declare const CEP_MASK = "_____-___";
export declare const CNPJ_MASK = "__.___.___/____-__";
export declare const CPF_MASK = "___.___.___-__";
export declare const DATA_MASK = "DD/MM/AAAA";
export declare class StringFormatter {
    private formattedMaskArray;
    private unchangeMask;
    private maskCharsSet;
    private readonly placeholderChar;
    private readonly emptyString;
    private caretPosition;
    /**
     * Retorna um texto formatado usando uma máscara
     * @param txt Texto a ser formatado
     * @param mask máscara
     * @param maskChars (opcional) caracteres da máscara, por exemplo:
     * A máscara DD/MM/AAAA tem que passar o maskChars como ['D', 'M', 'A'], para máscaras
     * como __/__/____ o valor de maskChars é opcional pois é obtido automaticamente, ficando
     * igual a ['_']
     */
    static maskedFormatter(txt: string, mask: string, maskChars?: string[]): string;
    /**
     * Retorna uma instância do StringFormatter
     * @param mask máscara
     * @param maskChars (opcional) caracteres da máscara, por exemplo:
     * A máscara DD/MM/AAAA tem que passar o maskChars como ['D', 'M', 'A'], para máscaras
     * como __/__/____ o valor de maskChars é opcional pois é obtido automaticamente, ficando
     * igual a ['_']
     */
    static getStringFormatter(mask: string, maskChars?: string[]): StringFormatter;
    /**
     * Remove a formatação de uma máscara de um texto
     * @param txt Texto a ser formatado
     * @param mask máscara
     * @param maskChars (opcional) caracteres da máscara, por exemplo:
     * A máscara DD/MM/AAAA tem que passar o maskChars como ['D', 'M', 'A'], para máscaras
     * como __/__/____ o valor de maskChars é opcional pois é obtido automaticamente, ficando
     * igual a ['_']
     */
    static clearFormat(txt: string, mask: string, maskChars?: string[]): string;
    /**
     * Aplica uma máscara a uma string
     *
     * @param mask A máscara desejada
     * @param maskCharsArray (Opcional) um array contendo as strings da máscara, por exemplo
     * a máscara DD/MM/AAAA tem que passar o maskCharsArray como ['D', 'M', 'A'], para máscaras
     * como __/__/____ esse valor de maskCharsArray é opcional, ficando igual a ['_']
     */
    constructor(mask: string, maskCharsArray?: string[]);
    /**
     * Retorna um texto sem a formatação da máscara
     * @param maskedTxt Texto formatado
     */
    stripMask(maskedTxt: string): string;
    /**
     * Retorna a posição que o cursor deve ter
     */
    getCaretPosition(): number;
    /**
     * Retorna o texto formatado
     * @param txt texto a ser formatado
     */
    format(txt: string): string;
    private getPlaceholderChar(str);
}
